@@ -26,9 +26,9 @@ override('do_layout', sub {
     # This loop takes each component and adds it's width and height to the
     # 'edge' on which is positioned.  At the end will know how much width and
     # height we need for each edge.
-    foreach my $c (@{ $container->components }) {
+    for(my $i = 0; $i < scalar(@{ $container->components }); $i++) {
 
-        my $comp = $c->{component};
+        my $comp = $container->get_component($i);
 
         next unless defined($comp) && $comp->visible;
 
@@ -36,7 +36,7 @@ override('do_layout', sub {
         $comp->width($comp->minimum_width);
         $comp->height($comp->minimum_height);
 
-        my $args = lc(substr($c->{args}, 0, 1));
+        my $args = lc(substr($container->get_constraint($i), 0, 1));
 
         if($comp->can('do_layout')) {
             $self->_layout_container($comp);
@@ -158,6 +158,11 @@ override('do_layout', sub {
             $i++;
         }
     }
+
+    foreach my $comp (@{ $container->components }) {
+        $comp->prepared(1) if defined($comp);
+    }
+
     $container->prepared(1);
     return 1;
 });
